==> wordpressify-0.4.0-4.tgz: package/README.md <==
# [![WordPressify](https://wordpressify.s3-eu-west-1.amazonaws.com/img/wordpressify-repository-logo.svg#3)](https://www.wordpressify.co/)

[![Version](https://img.shields.io/github/package-json/v/luangjokaj/wordpressify)](https://www.wordpressify.co/)

Automate your WordPress development workflow.

---

## Documentation

For full documentation, visit https://www.wordpressify.co.

### Changelog

For a list of changes, check out the [changelog](CHANGELOG.md).

## Community

For help, discussion about best practices, or any other conversation that would benefit from being searchable:

[Discuss WordPressify on GitHub](https://github.com/luangjokaj/wordpressify/discussions)

For casual chit-chat with others using WordPressify:

[Join the Discord Server](https://discord.com/invite/uQFdMddMZw)

# Core Team

<table>
  <tbody>
    <tr>
      <td align="center" valign="top">
        <a href="https://github.com/luangjokaj">
            <img width="150" height="150" src="https://github.com/luangjokaj.png">
        </a>
        <br>
        <a href="https://github.com/luangjokaj">Luan Gjokaj</a><br />
      </td>
      <td align="center" valign="top">
        <a href="https://github.com/ribaricplusplus">
            <img width="150" height="150" src="https://github.com/ribaricplusplus.png">
        </a>
        <br>
        <a href="https://github.com/ribaricplusplus">Bruno Ribarić</a>
      </td>
      <td align="center" valign="top">
        <a href="https://github.com/mountainash">
            <img width="150" height="150" src="https://github.com/mountainash.png">
        </a>
        <br>
        <a href="https://github.com/mountainash">Mountain/\Ash</a>
      </td>
     </tr>
  </tbody>
</table>

==> wordpressify-0.4.0-7.tgz: package/README.md <==
# [![WordPressify](https://wordpressify.s3-eu-west-1.amazonaws.com/img/wordpressify-repository-logo.svg#3)](https://www.wordpressify.co/)

[![Version](https://img.shields.io/github/package-json/v/luangjokaj/wordpressify)](https://www.wordpressify.co/)

Automate your WordPress development workflow.

---

## Documentation

For full documentation, visit https://www.wordpressify.co.

### Changelog

For a list of changes, check out the [changelog](CHANGELOG.md).

## Community

For help, discussion about best practices, or any other conversation that would benefit from being searchable:

[Discuss WordPressify on GitHub](https://github.com/luangjokaj/wordpressify/discussions)

For casual chit-chat with others using WordPressify:

[Join the Discord Server](https://discord.com/invite/uQFdMddMZw)

# Core Team

<table>
  <tbody>
    <tr>
      <td align="center" valign="top">
        <a href="https://github.com/luangjokaj">
            <img width="100" height="auto" src="https://github.com/luangjokaj.png">
        </a>
        <br>
        <a href="https://github.com/luangjokaj">Luan Gjokaj</a><br />
      </td>
      <td align="center" valign="top">
        <a href="https://github.com/ribaricplusplus">
            <img width="100" height="auto" src="https://github.com/ribaricplusplus.png">
        </a>
        <br>
        <a href="https://github.com/ribaricplusplus">Bruno Ribarić</a>
      </td>
      <td align="center" valign="top">
        <a href="https://github.com/mountainash">
            <img width="100" height="auto" src="https://github.com/mountainash.png">
        </a>
        <br>
        <a href="https://github.com/mountainash">Mountain Ash</a>
      </td>
     </tr>
  </tbody>
</table>
